@@ -5,15 +5,37 @@ use OpenAPI::Client;
 use Mojo::JSON qw(encode_json decode_json j);
 use Mojo::Util qw(encode getopt);
 
+use constant YAML => eval 'require YAML::XS;1';
+
+sub _say { length && say encode('UTF-8', $_) for @_ }
+sub _warn { warn @_ }
+
 has description => 'Perform Open API requests';
 has usage => sub { shift->extract_usage . "\n" };
 
+has _client => undef;
+has _ops    => sub {
+  my $client = shift->_client;
+  my $paths = $client->validator->schema->get('/paths') || {};
+  my %ops;
+
+  for my $path (keys %$paths) {
+    for my $http_method (keys %{$paths->{$path}}) {
+      my $op_spec = $paths->{$path}{$http_method};
+      $ops{$op_spec->{operationId}} = $op_spec if $op_spec->{operationId};
+    }
+  }
+
+  return \%ops;
+};
+
 sub run {
   my ($self, @args) = @_;
-  my %ua;
+  my ($info_about, %ua);
 
   getopt \@args,
     'i|inactivity-timeout=i' => sub { $ua{inactivity_timeout} = $_[1] },
+    'I|information=s'        => \$info_about,
     'o|connect-timeout=i'    => sub { $ua{connect_timeout}    = $_[1] },
     'p|parameter=s'          => \my %parameters,
     'c|content=s'            => \my $content,
@@ -21,7 +43,7 @@ sub run {
     'v|verbose'              => \my $verbose;
 
   my @client_args = (shift @args);
-  my $op          = shift @args;
+  my $op          = $info_about || shift @args;
   my $selector    = shift @args // '';
 
   die $self->usage unless $client_args[0];
@@ -33,39 +55,50 @@ sub run {
   }
 
   push @client_args, app => $self->app if $client_args[0] =~ m!^/! and !-e $client_args[0];
-  my $client = OpenAPI::Client->new(@client_args);
-  return _say("$client_args[0] is valid.") unless $op;
-  die qq(Unknown operationId "$op".\n) unless $client->can($op);
+  $self->_client(OpenAPI::Client->new(@client_args));
+  return $self->_info($info_about) if $info_about;
+  return $self->_list unless $op;
+  die qq(Unknown operationId "$op".\n) unless $self->_client->can($op);
 
-  $client->ua->proxy->detect unless $ENV{OPENAPI_NO_PROXY};
-  $client->ua->$_($ua{$_}) for keys %ua;
-  $client->ua->on(
+  $self->_client->ua->proxy->detect unless $ENV{OPENAPI_NO_PROXY};
+  $self->_client->ua->$_($ua{$_}) for keys %ua;
+  $self->_client->ua->on(
     start => sub {
       my ($ua, $tx) = @_;
       weaken $tx;
-      $tx->res->content->on(body => sub { _warn(_header($tx->req), _header($tx->res)) }) if $verbose;
+      $tx->res->content->on(body => sub { _warn _header($tx->req), _header($tx->res) }) if $verbose;
     }
   );
 
-  my $tx = $client->$op(\%parameters, defined $content ? (body => decode_json $content) : ());
+  my $tx = $self->_client->$op(\%parameters, defined $content ? (body => decode_json $content) : ());
   if ($tx->error and $tx->error->{message} eq 'Invalid input') {
-    _warn(_header($tx->req), _header($tx->res)) if $verbose;
+    _warn _header($tx->req), _header($tx->res) if $verbose;
   }
 
   return _json($tx->res->json, $selector) if !length $selector || $selector =~ m!^/!;
-  return _say($tx->res->dom->find($selector)->each);
+  return _say $tx->res->dom->find($selector)->each;
 }
 
 sub _header { $_[0]->build_start_line, $_[0]->headers->to_string, "\n\n" }
 
-sub _json {
-  return unless defined(my $data = Mojo::JSON::Pointer->new(shift)->get(shift));
-  return _say($data) unless ref $data eq 'HASH' || ref $data eq 'ARRAY';
-  _say(encode_json($data));
+sub _info {
+  my ($self, $op) = @_;
+  my $op_spec = $self->_ops->{$op};
+  return _warn qq(Could not find the given operationId "$op".\n) unless $op_spec;
+  return _say YAML ? YAML::XS::Dump($op_spec) : Mojo::Util::dumper($op_spec);
 }
 
-sub _say { length && say encode('UTF-8', $_) for @_ }
-sub _warn { warn @_ }
+sub _json {
+  return unless defined(my $data = Mojo::JSON::Pointer->new(shift)->get(shift));
+  return _say $data unless ref $data eq 'HASH' || ref $data eq 'ARRAY';
+  _say encode_json $data;
+}
+
+sub _list {
+  my $self = shift;
+  _warn "--- Operations for @{[$self->_client->base_url]}\n";
+  _say $_ for sort keys %{$self->_ops};
+}
 
 1;
 
